@@ -7,7 +7,11 @@ rustup run nightly cbindgen \
   --config cbindgen.toml \
   --crate pact_ffi \
   --output include/pact.h
-cp include/pact.h ../target/artifacts
+rustup run nightly cbindgen \
+  --config cbindgen-c++.toml \
+  --crate pact_ffi \
+  --output include/pact-cpp.h
+cp include/*.h ../target/artifacts
 gzip -c ../target/release/libpact_ffi.so > ../target/artifacts/libpact_ffi-linux-x86_64.so.gz
 openssl dgst -sha256 -r ../target/artifacts/libpact_ffi-linux-x86_64.so.gz > ../target/artifacts/libpact_ffi-linux-x86_64.so.gz.sha256
 gzip -c ../target/release/libpact_ffi.a > ../target/artifacts/libpact_ffi-linux-x86_64.a.gz
