@@ -86,6 +86,7 @@ impl VerifierHandle {
     enable_pending: bool,
     include_wip_pacts_since: Option<String>,
     provider_tags: Vec<String>,
+    provider_branch: Option<String>,
     selectors: Vec<ConsumerVersionSelector>,
     auth: &HttpAuth
   ) {
@@ -96,6 +97,7 @@ impl VerifierHandle {
         enable_pending,
         include_wip_pacts_since,
         provider_tags,
+        provider_branch,
         selectors,
         auth: Some(auth.clone()),
         links: vec![]
@@ -107,6 +109,7 @@ impl VerifierHandle {
         enable_pending,
         include_wip_pacts_since,
         provider_tags,
+        provider_branch,
         selectors,
         auth: None,
         links: vec![]
@@ -159,6 +162,11 @@ impl VerifierHandle {
   }
 
   /// Execute the verifier
+  ///
+  /// This will return an integer value based on the status of the verification:
+  /// * 0 - verification was successful
+  /// * 1 - verification was not successful
+  /// * 2 - failed to run the verification
   pub fn execute(&self) -> i32 {
     let filter = FilterInfo::None;
 
@@ -168,19 +176,17 @@ impl VerifierHandle {
 
     let runtime = tokio::runtime::Runtime::new().unwrap();
     runtime.block_on(async {
-      if verify_provider_async(
+      verify_provider_async(
         self.provider.clone(),
         self.sources.clone(),
         filter,
         self.consumers.clone(),
         self.options.clone(),
         &self.state_change.clone()
-      ).await {
-        0
-      } else {
-        1
-      }
+      ).await
     })
+      .map(|result| if result { 0 } else { 2 })
+      .unwrap_or(2)
   }
 }
 
